@@ -479,3 +479,39 @@ void _logMsgForJobId(const AB_BANKING *ab, uint32_t jobId, const char *msg)
 }
 
 
+
+void AB_Banking_Iso8859_1ToUtf8(const char *p, int size, GWEN_BUFFER *buf)
+{
+  while (*p) {
+    unsigned int c;
+
+    if (!size)
+      break;
+
+    c=(unsigned char)(*(p++));
+    if (c!=10) { // keep linefeed as is
+      if (c<32 || c==127)
+        c=32;
+      else {
+        /* Dirty hack to support Unicode code points */
+        /* U+00A0..U+00FF already in UTF-8 encoding. */
+        /* E.g. German Umlaute from Consorsbank      */
+        unsigned int c2 = (unsigned char)(*p);
+        if ((c & ~0x01)==0xC2 && (c2 & ~0x3F)==0x80) {
+          GWEN_Buffer_AppendByte(buf, c);
+          c=(unsigned char)(*(p++));
+        }
+        else if (c & 0x80) {
+          GWEN_Buffer_AppendByte(buf, 0xc0 | c>>6);
+          c &= ~0x40;
+        }
+      }
+    }
+    GWEN_Buffer_AppendByte(buf, c);
+    if (size!=-1)
+      size--;
+  } /* while */
+}
+
+
+
