@@ -12,6 +12,8 @@
 # include <config.h>
 #endif
 
+#define AQBANKING_NOWARN_DEPRECATED
+
 #include "abgui_p.h"
 
 #include <gwenhywfar/mdigest.h>
@@ -422,6 +424,8 @@ int GWENHYWFAR_CB AB_Gui_ReadDialogPrefs(GWEN_GUI *gui,
 {
   AB_GUI *xgui;
 
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Reading dialog preferences for \"%s\"", groupName);
+
   assert(gui);
   xgui=GWEN_INHERIT_GETDATA(GWEN_GUI, AB_GUI, gui);
   assert(xgui);
@@ -466,6 +470,8 @@ int GWENHYWFAR_CB AB_Gui_WriteDialogPrefs(GWEN_GUI *gui,
 {
   AB_GUI *xgui;
 
+  DBG_INFO(AQBANKING_LOGDOMAIN, "Writing dialog preferences for \"%s\"", groupName);
+
   assert(gui);
   xgui=GWEN_INHERIT_GETDATA(GWEN_GUI, AB_GUI, gui);
   assert(xgui);
