@@ -12,8 +12,8 @@
 # include <config.h>
 #endif
 
-#include "session/pintan/s_encrypt_pintan.h"
-#include "parser/parser.h"
+#include "libaqfints/session/pintan/s_encrypt_pintan.h"
+#include "libaqfints/parser/parser.h"
 
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/debug.h>
