@@ -13,8 +13,8 @@
 #define AH_JOBGETBANKINFO_L_H
 
 
-#include "aqhbci_l.h"
-#include "job_l.h"
+#include "aqhbci/aqhbci_l.h"
+#include "aqhbci/joblayer/job_l.h"
 
 
 
