@@ -640,6 +640,9 @@ GWEN_DB_NODE *_sampleResponseSegments(AH_JOBQUEUE *jq, AH_MSG *msg, GWEN_DB_NODE
     GWEN_DB_AddGroup(dbData, GWEN_DB_Group_dup(dbCurr));
 
     GWEN_DB_AddGroup(dbAllResponses, dbPreparedJobResponse);
+
+    if (strcasecmp(GWEN_DB_GroupName(dbCurr), "SegResult")!=0 && strcasecmp(GWEN_DB_GroupName(dbCurr), "MsgResult")!=0)
+      AH_JobQueue_AddToAllResponses(jq, dbPreparedJobResponse); /* add all responses to queue */
     responsesAdded++;
 
     dbCurr=GWEN_DB_GetNextGroup(dbCurr);
@@ -761,14 +764,19 @@ void _handleResponseSegments(AH_JOBQUEUE *jq, AH_MSG *msg, GWEN_DB_NODE *db, GWE
     if (AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_IGNOREACCOUNTS) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Ignoring possibly received accounts");
     }
-    else
+    else {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Reading possibly received accounts and SEPA accounts");
       AH_JobQueue_ReadAccounts(jq, dbAllResponses);
+      AH_JobQueue_ReadSepaAccounts(jq, dbAllResponses);
+    }
 
     jqRun=jq;
     while (jqRun) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Dispatching responses to queue %d", queueNum);
+#if 0
       if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Info)
         AH_JobQueue_DumpJobList(jqRun, stderr, 2);
+#endif
       /* then dispatch to jobs in this and in reference queue */
       _dispatchResponsesToJobQueue(jqRun, dbAllResponses, (queueNum>0)?1:0);
       queueNum++;
